/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#include <sys/types.h>
#include <sys/socket.h>

extern void fatal(const char *, ...);

int
initserver(int type, struct sockaddr *addrp, uint_t alen,
	uint_t qlen)
{
	int fd;

	/*
	 * Create a socket endpoint.
	 */
	if ((fd = socket(addrp->sa_family, type, 0)) < 0)
		fatal("cannot create socket");

	/*
	 * Bind the specified address.
	 */
	if (bind(fd, addrp, alen) < 0)
		fatal("cannot bind address");

	/*
	 * If this is a stream socket, inform the transport
	 * provider of the queue length (backlog), indicating
	 * that the server is willing to accept connections.
	 */
	if (type == SOCK_STREAM)
		listen(fd, qlen);

	/*
	 * Return the endpoint.
	 */
	return(fd);
}
